Learn R Programming

sensitivityIxJ (version 0.1.5)

estimate_tables: Estimate the Total Number of Tables

Description

This function estimates the total number of tables satisfying the margin constraints. We recommend the readers to use this before determining the number of Monte Carlo simulations for the sampling-based p-value calculation.

Usage

estimate_tables(treatment.margins, outcome.margins)

Value

this function returns the estimated total number of tables satisfying the margin constraints.

Arguments

treatment.margins

A vector specifying the total number of subjects receiving each treatment level. The first entry of this vector represents the number of subjects receiving the first treatment level in the study.

outcome.margins

A vector specifying the total number of subjects showing each outcome level. The first entry of this vector represents the number of subjects showing the first outcome level in the study.